@@ -852,11 +852,12 @@ class Screen:
         parent = self.parent.id if self.parent else None
         if parent is not None and parent < 0:
             return
-        expanded_nodes, selected_nodes = [], []
+        state = self.tree_states[parent][view.children_field]
+        if state:
+            expanded_nodes, selected_nodes = state
+        else:
+            expanded_nodes, selected_nodes = [], []
         if view.view_type in {'tree', 'list-form'}:
-            state = self.tree_states[parent][view.children_field]
-            if state:
-                expanded_nodes, selected_nodes = state
             if (state is None
                     and CONFIG['client.save_tree_state']
                     and int(view.attributes.get('tree_state', False))):
@@ -904,7 +905,8 @@ class Screen:
                     for widget in widgets:
                         if hasattr(widget, 'screen'):
                             widget.screen.save_tree_state(store)
-                if len(self.views) == 1 and self.current_record:
+            if view == self.current_view and view.view_type == 'form':
+                if self.current_record:
                     path = self.current_record.id
                     if path < 0:
                         path = -self.current_record.group.index(
@@ -918,8 +920,9 @@ class Screen:
                 else:
                     paths = []
                 selected_paths = view.get_selected_paths()
-                self.tree_states[parent][view.children_field] = (
-                    paths, selected_paths)
+                if view == self.current_view:
+                    self.tree_states[parent][view.children_field] = (
+                        paths, selected_paths)
                 if (store
                         and int(view.attributes.get('tree_state', False))
                         and CONFIG['client.save_tree_state']):
